@@ -84,6 +84,17 @@ class Warnings(object):
     W018 = ("Entity '{entity}' already exists in the Knowledge base.")
     W019 = ("Changing vectors name from {old} to {new}, to avoid clash with "
             "previously loaded vectors. See Issue #3853.")
+    W020 = ("Unnamed vectors. This won't allow multiple vectors models to be "
+            "loaded. (Shape: {shape})")
+    W021 = ("Unexpected hash collision in PhraseMatcher. Matches may be "
+            "incorrect. Modify PhraseMatcher._terminal_hash to fix.")
+    W022 = ("Training a new part-of-speech tagger using a model with no "
+            "lemmatization rules or data. This means that the trained model "
+            "may not be able to lemmatize correctly. If this is intentional "
+            "or the language you're using doesn't have lemmatization data, "
+            "you can ignore this warning by setting SPACY_WARNING_IGNORE=W022. "
+            "If this is surprising, make sure you have the spacy-lookups-data "
+            "package installed.")
 
 
 @add_codes
@@ -118,13 +129,14 @@ class Errors(object):
     E011 = ("Unknown operator: '{op}'. Options: {opts}")
     E012 = ("Cannot add pattern for zero tokens to matcher.\nKey: {key}")
     E013 = ("Error selecting action in matcher")
-    E014 = ("Uknown tag ID: {tag}")
+    E014 = ("Unknown tag ID: {tag}")
     E015 = ("Conflicting morphology exception for ({tag}, {orth}). Use "
             "`force=True` to overwrite.")
     E016 = ("MultitaskObjective target should be function or one of: dep, "
             "tag, ent, dep_tag_offset, ent_tag.")
     E017 = ("Can only add unicode or bytes. Got type: {value_type}")
-    E018 = ("Can't retrieve string for hash '{hash_value}'.")
+    E018 = ("Can't retrieve string for hash '{hash_value}'. This usually "
+            "refers to an issue with the `Vocab` or `StringStore`.")
     E019 = ("Can't create transition with unknown action ID: {action}. Action "
             "IDs are enumerated in spacy/syntax/{src}.pyx.")
     E020 = ("Could not find a gold-standard action to supervise the "
@@ -242,7 +254,8 @@ class Errors(object):
             "Tag sequence:\n{tags}")
     E068 = ("Invalid BILUO tag: '{tag}'.")
     E069 = ("Invalid gold-standard parse tree. Found cycle between word "
-            "IDs: {cycle}")
+            "IDs: {cycle} (tokens: {cycle_tokens}) in the document starting "
+            "with tokens: {doc_tokens}.")
     E070 = ("Invalid gold-standard data. Number of documents ({n_docs}) "
             "does not align with number of annotations ({n_annots}).")
     E071 = ("Error creating lexeme: specified orth ID ({orth}) does not "
@@ -311,10 +324,12 @@ class Errors(object):
     E101 = ("NODE_NAME should be a new node and NBOR_NAME should already have "
             "have been declared in previous edges.")
     E102 = ("Can't merge non-disjoint spans. '{token}' is already part of "
-            "tokens to merge.")
-    E103 = ("Trying to set conflicting doc.ents: '{span1}' and '{span2}'. A token"
-            " can only be part of one entity, so make sure the entities you're "
-            "setting don't overlap.")
+            "tokens to merge. If you want to find the longest non-overlapping "
+            "spans, you can use the util.filter_spans helper:\n"
+            "https://spacy.io/api/top-level#util.filter_spans")
+    E103 = ("Trying to set conflicting doc.ents: '{span1}' and '{span2}'. A "
+            "token can only be part of one entity, so make sure the entities "
+            "you're setting don't overlap.")
     E104 = ("Can't find JSON schema for '{name}'.")
     E105 = ("The Doc.print_tree() method is now deprecated. Please use "
             "Doc.to_json() instead or write your own function.")
@@ -324,8 +339,8 @@ class Errors(object):
     E108 = ("As of spaCy v2.1, the pipe name `sbd` has been deprecated "
             "in favor of the pipe name `sentencizer`, which does the same "
             "thing. For example, use `nlp.create_pipeline('sentencizer')`")
-    E109 = ("Model for component '{name}' not initialized. Did you forget to load "
-            "a model, or forget to call begin_training()?")
+    E109 = ("Model for component '{name}' not initialized. Did you forget to "
+            "load a model, or forget to call begin_training()?")
     E110 = ("Invalid displaCy render wrapper. Expected callable, got: {obj}")
     E111 = ("Pickling a token is not supported, because tokens are only views "
             "of the parent Doc and can't exist on their own. A pickled token "
@@ -341,7 +356,7 @@ class Errors(object):
     E113 = ("The newly split token can only have one root (head = 0).")
     E114 = ("The newly split token needs to have a root (head = 0).")
     E115 = ("All subtokens must have associated heads.")
-    E116 = ("Cannot currently add labels to pre-trained text classifier. Add "
+    E116 = ("Cannot currently add labels to pretrained text classifier. Add "
             "labels before training begins. This functionality was available "
             "in previous versions, but had significant bugs that led to poor "
             "performance.")
@@ -350,12 +365,12 @@ class Errors(object):
     E118 = ("The custom extension attribute '{attr}' is not registered on the "
             "Token object so it can't be set during retokenization. To "
             "register an attribute, use the Token.set_extension classmethod.")
-    E119 = ("Can't set custom extension attribute '{attr}' during retokenization "
-            "because it's not writable. This usually means it was registered "
-            "with a getter function (and no setter) or as a method extension, "
-            "so the value is computed dynamically. To overwrite a custom "
-            "attribute manually, it should be registered with a default value "
-            "or with a getter AND setter.")
+    E119 = ("Can't set custom extension attribute '{attr}' during "
+            "retokenization because it's not writable. This usually means it "
+            "was registered with a getter function (and no setter) or as a "
+            "method extension, so the value is computed dynamically. To "
+            "overwrite a custom attribute manually, it should be registered "
+            "with a default value or with a getter AND setter.")
     E120 = ("Can't set custom extension attributes during retokenization. "
             "Expected dict mapping attribute names to values, but got: {value}")
     E121 = ("Can't bulk merge spans. Attribute length {attr_len} should be "
@@ -373,50 +388,124 @@ class Errors(object):
             "is now deprecated. Please use the `exclude` argument instead. "
             "For example: exclude=['{arg}'].")
     E129 = ("Cannot write the label of an existing Span object because a Span "
-            "is a read-only view of the underlying Token objects stored in the Doc. "
-            "Instead, create a new Span object and specify the `label` keyword argument, "
-            "for example:\nfrom spacy.tokens import Span\n"
+            "is a read-only view of the underlying Token objects stored in the "
+            "Doc. Instead, create a new Span object and specify the `label` "
+            "keyword argument, for example:\nfrom spacy.tokens import Span\n"
             "span = Span(doc, start={start}, end={end}, label='{label}')")
     E130 = ("You are running a narrow unicode build, which is incompatible "
             "with spacy >= 2.1.0. To fix this, reinstall Python and use a wide "
             "unicode build instead. You can also rebuild Python and set the "
             "--enable-unicode=ucs4 flag.")
     E131 = ("Cannot write the kb_id of an existing Span object because a Span "
-            "is a read-only view of the underlying Token objects stored in the Doc. "
-            "Instead, create a new Span object and specify the `kb_id` keyword argument, "
-            "for example:\nfrom spacy.tokens import Span\n"
-            "span = Span(doc, start={start}, end={end}, label='{label}', kb_id='{kb_id}')")
-    E132 = ("The vectors for entities and probabilities for alias '{alias}' should have equal length, "
-            "but found {entities_length} and {probabilities_length} respectively.")
-    E133 = ("The sum of prior probabilities for alias '{alias}' should not exceed 1, "
-            "but found {sum}.")
+            "is a read-only view of the underlying Token objects stored in "
+            "the Doc. Instead, create a new Span object and specify the "
+            "`kb_id` keyword argument, for example:\nfrom spacy.tokens "
+            "import Span\nspan = Span(doc, start={start}, end={end}, "
+            "label='{label}', kb_id='{kb_id}')")
+    E132 = ("The vectors for entities and probabilities for alias '{alias}' "
+            "should have equal length, but found {entities_length} and "
+            "{probabilities_length} respectively.")
+    E133 = ("The sum of prior probabilities for alias '{alias}' should not "
+            "exceed 1, but found {sum}.")
     E134 = ("Alias '{alias}' defined for unknown entity '{entity}'.")
     E135 = ("If you meant to replace a built-in component, use `create_pipe`: "
             "`nlp.replace_pipe('{name}', nlp.create_pipe('{name}'))`")
     E136 = ("This additional feature requires the jsonschema library to be "
             "installed:\npip install jsonschema")
-    E137 = ("Expected 'dict' type, but got '{type}' from '{line}'. Make sure to provide a valid JSON "
-            "object as input with either the `text` or `tokens` key. For more info, see the docs:\n"
+    E137 = ("Expected 'dict' type, but got '{type}' from '{line}'. Make sure "
+            "to provide a valid JSON object as input with either the `text` "
+            "or `tokens` key. For more info, see the docs:\n"
             "https://spacy.io/api/cli#pretrain-jsonl")
-    E138 = ("Invalid JSONL format for raw text '{text}'. Make sure the input includes either the "
-            "`text` or `tokens` key. For more info, see the docs:\n"
-            "https://spacy.io/api/cli#pretrain-jsonl")
-    E139 = ("Knowledge base for component '{name}' not initialized. Did you forget to call set_kb()?")
-    E140 = ("The list of entities, prior probabilities and entity vectors should be of equal length.")
-    E141 = ("Entity vectors should be of length {required} instead of the provided {found}.")
-    E142 = ("Unsupported loss_function '{loss_func}'. Use either 'L2' or 'cosine'")
-    E143 = ("Labels for component '{name}' not initialized. Did you forget to call add_label()?")
+    E138 = ("Invalid JSONL format for raw text '{text}'. Make sure the input "
+            "includes either the `text` or `tokens` key. For more info, see "
+            "the docs:\nhttps://spacy.io/api/cli#pretrain-jsonl")
+    E139 = ("Knowledge base for component '{name}' not initialized. Did you "
+            "forget to call set_kb()?")
+    E140 = ("The list of entities, prior probabilities and entity vectors "
+            "should be of equal length.")
+    E141 = ("Entity vectors should be of length {required} instead of the "
+            "provided {found}.")
+    E142 = ("Unsupported loss_function '{loss_func}'. Use either 'L2' or "
+            "'cosine'.")
+    E143 = ("Labels for component '{name}' not initialized. Did you forget to "
+            "call add_label()?")
+    E144 = ("Could not find parameter `{param}` when building the entity "
+            "linker model.")
+    E145 = ("Error reading `{param}` from input file.")
+    E146 = ("Could not access `{path}`.")
+    E147 = ("Unexpected error in the {method} functionality of the "
+            "EntityLinker: {msg}. This is likely a bug in spaCy, so feel free "
+            "to open an issue.")
+    E148 = ("Expected {ents} KB identifiers but got {ids}. Make sure that "
+            "each entity in `doc.ents` is assigned to a KB identifier.")
+    E149 = ("Error deserializing model. Check that the config used to create "
+            "the component matches the model being loaded.")
+    E150 = ("The language of the `nlp` object and the `vocab` should be the "
+            "same, but found '{nlp}' and '{vocab}' respectively.")
+    E151 = ("Trying to call nlp.update without required annotation types. "
+            "Expected top-level keys: {exp}. Got: {unexp}.")
+    E152 = ("The attribute {attr} is not supported for token patterns. "
+            "Please use the option validate=True with Matcher, PhraseMatcher, "
+            "or EntityRuler for more details.")
+    E153 = ("The value type {vtype} is not supported for token patterns. "
+            "Please use the option validate=True with Matcher, PhraseMatcher, "
+            "or EntityRuler for more details.")
+    E154 = ("One of the attributes or values is not supported for token "
+            "patterns. Please use the option validate=True with Matcher, "
+            "PhraseMatcher, or EntityRuler for more details.")
+    E155 = ("The pipeline needs to include a tagger in order to use "
+            "Matcher or PhraseMatcher with the attributes POS, TAG, or LEMMA. "
+            "Try using nlp() instead of nlp.make_doc() or list(nlp.pipe()) "
+            "instead of list(nlp.tokenizer.pipe()).")
+    E156 = ("The pipeline needs to include a parser in order to use "
+            "Matcher or PhraseMatcher with the attribute DEP. Try using "
+            "nlp() instead of nlp.make_doc() or list(nlp.pipe()) instead of "
+            "list(nlp.tokenizer.pipe()).")
+    E157 = ("Can't render negative values for dependency arc start or end. "
+            "Make sure that you're passing in absolute token indices, not "
+            "relative token offsets.\nstart: {start}, end: {end}, label: "
+            "{label}, direction: {dir}")
+    E158 = ("Can't add table '{name}' to lookups because it already exists.")
+    E159 = ("Can't find table '{name}' in lookups. Available tables: {tables}")
+    E160 = ("Can't find language data file: {path}")
+    E161 = ("Found an internal inconsistency when predicting entity links. "
+            "This is likely a bug in spaCy, so feel free to open an issue.")
+    E162 = ("Cannot evaluate textcat model on data with different labels.\n"
+            "Labels in model: {model_labels}\nLabels in evaluation "
+            "data: {eval_labels}")
+    E163 = ("cumsum was found to be unstable: its last element does not "
+            "correspond to sum")
+    E164 = ("x is neither increasing nor decreasing: {}.")
+    E165 = ("Only one class present in y_true. ROC AUC score is not defined in "
+            "that case.")
+    E166 = ("Can only merge DocBins with the same pre-defined attributes.\n"
+            "Current DocBin: {current}\nOther DocBin: {other}")
+    E167 = ("Unknown morphological feature: '{feat}' ({feat_id}). This can "
+            "happen if the tagger was trained with a different set of "
+            "morphological features. If you're using a pretrained model, make "
+            "sure that your models are up to date:\npython -m spacy validate")
+    E168 = ("Unknown field: {field}")
+    E169 = ("Can't find module: {module}")
+    E170 = ("Cannot apply transition {name}: invalid for the current state.")
+    E171 = ("Matcher.add received invalid on_match callback argument: expected "
+            "callable or None, but got: {arg_type}")
+    E172 = ("The Lemmatizer.load classmethod is deprecated. To create a "
+            "Lemmatizer, initialize the class directly. See the docs for "
+            "details: https://spacy.io/api/lemmatizer")
+    E173 = ("As of v2.2, the Lemmatizer is initialized with an instance of "
+            "Lookups containing the lemmatization tables. See the docs for "
+            "details: https://spacy.io/api/lemmatizer#init")
 
 
 @add_codes
 class TempErrors(object):
-    T003 = ("Resizing pre-trained Tagger models is not currently supported.")
+    T003 = ("Resizing pretrained Tagger models is not currently supported.")
     T004 = ("Currently parser depth is hard-coded to 1. Received: {value}.")
     T007 = ("Can't yet set {attr} from Span. Vote for this feature on the "
             "issue tracker: http://github.com/explosion/spaCy/issues")
     T008 = ("Bad configuration of Tagger. This is probably a bug within "
             "spaCy. We changed the name of an internal attribute for loading "
-            "pre-trained vectors, and the class has been passed the old name "
+            "pretrained vectors, and the class has been passed the old name "
             "(pretrained_dims) but not the new name (pretrained_vectors).")
 
 
