@@ -14,6 +14,7 @@ import functools
 import itertools
 import numpy.random
 import srsly
+import sys
 
 try:
     import jsonschema
@@ -36,6 +37,15 @@ _data_path = Path(__file__).parent / "data"
 _PRINT_ENV = False
 
 
+class ENTRY_POINTS(object):
+    """Available entry points to register extensions."""
+
+    factories = "spacy_factories"
+    languages = "spacy_languages"
+    displacy_colors = "spacy_displacy_colors"
+    lookups = "spacy_lookups"
+
+
 def set_env_log(value):
     global _PRINT_ENV
     _PRINT_ENV = value
@@ -61,7 +71,7 @@ def get_lang_class(lang):
     """
     global LANGUAGES
     # Check if an entry point is exposed for the language code
-    entry_point = get_entry_point("spacy_languages", lang)
+    entry_point = get_entry_point(ENTRY_POINTS.languages, lang)
     if entry_point is not None:
         LANGUAGES[lang] = entry_point
         return entry_point
@@ -117,6 +127,28 @@ def ensure_path(path):
         return path
 
 
+def load_language_data(path):
+    """Load JSON language data using the given path as a base. If the provided
+    path isn't present, will attempt to load a gzipped version before giving up.
+
+    path (unicode / Path): The data to load.
+    RETURNS: The loaded data.
+    """
+    path = ensure_path(path)
+    if path.exists():
+        return srsly.read_json(path)
+    path = path.with_suffix(path.suffix + ".gz")
+    if path.exists():
+        return srsly.read_gzip_json(path)
+    raise ValueError(Errors.E160.format(path=path2str(path)))
+
+
+def get_module_path(module):
+    if not hasattr(module, "__module__"):
+        raise ValueError(Errors.E169.format(module=repr(module)))
+    return Path(sys.modules[module.__module__].__file__).parent
+
+
 def load_model(name, **overrides):
     """Load a model from a shortcut link, package or data path.
 
@@ -255,17 +287,19 @@ def get_entry_points(key):
     return result
 
 
-def get_entry_point(key, value):
+def get_entry_point(key, value, default=None):
     """Check if registered entry point is available for a given name and
     load it. Otherwise, return None.
 
     key (unicode): Entry point name.
     value (unicode): Name of entry point to load.
+    default: Optional default value to return.
     RETURNS: The loaded entry point or None.
     """
     for entry_point in pkg_resources.iter_entry_points(key):
         if entry_point.name == value:
             return entry_point.load()
+    return default
 
 
 def is_in_jupyter():
